summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/tests/FT_App/StubFaultNotifier.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/tests/FT_App/StubFaultNotifier.h')
-rw-r--r--TAO/orbsvcs/tests/FT_App/StubFaultNotifier.h24
1 files changed, 20 insertions, 4 deletions
diff --git a/TAO/orbsvcs/tests/FT_App/StubFaultNotifier.h b/TAO/orbsvcs/tests/FT_App/StubFaultNotifier.h
index 6daeeb9c49a..cf2abdf77c8 100644
--- a/TAO/orbsvcs/tests/FT_App/StubFaultNotifier.h
+++ b/TAO/orbsvcs/tests/FT_App/StubFaultNotifier.h
@@ -46,7 +46,7 @@ public:
/**
* Initialize.
*/
- int init (TAO_ORB_Manager & orbManager);
+ int init (CORBA::ORB_var & orb ACE_ENV_ARG_DECL);
/**
* Prepare to exit.
@@ -65,6 +65,12 @@ public:
*/
int idle(int &result);
+ // override virtuals
+::PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL);
+
+ PortableServer::ObjectId objectId()const;
+
+
/**
* Clean house for process shut down.
*/
@@ -120,8 +126,8 @@ public:
/////////////////
// Implementation
private:
- int writeIORFile();
- int readIORFile(const char * fileName, CORBA::String_var & ior);
+ int write_ior_file();
+ int read_ior_file(const char * fileName, CORBA::String_var & ior);
///////////////
// Data Members
@@ -132,7 +138,17 @@ private:
CORBA::ORB_var orb_;
/**
- * IOR of this object as assigned by orb.
+ * The POA used to activate this object.
+ */
+ PortableServer::POA_var poa_;
+
+ /**
+ * The CORBA object id assigned to this object.
+ */
+ PortableServer::ObjectId_var objectId_;
+
+ /**
+ * IOR of this object as assigned by poa
*/
CORBA::String_var ior_;